package net.user1.union.example.servermodule;

import org.apache.log4j.Logger;

import net.user1.union.api.Account;
import net.user1.union.api.Module;
import net.user1.union.api.Status;
import net.user1.union.core.context.ModuleContext;
import net.user1.union.core.exception.AccountNotFoundException;
import net.user1.union.core.exception.DatasourceException;

public class StartupServerModule implements Module {
    private static Logger s_log = Logger.getLogger(StartupServerModule.class); 
    
    public boolean init(ModuleContext ctx) {
        String status = ctx.getServer().createAccount("name", "password");
        if (Status.SUCCESS.equals(status) || Status.ACCOUNT_EXISTS.equals(status)) {
            try {
                Account account = ctx.getServer().getAccount("name");
                
                // if it already existed it likely is already moderator from the last server
                // start
                if (!account.isModerator()) {
                    account.setModerator(true);
                }
            } catch (AccountNotFoundException e) {
                // should never happen but return false to generate log
                return false;
            } catch (DatasourceException e) {
                s_log.error("Datasource could not set account to moderator.", e);
            }
        } else if (Status.ERROR.equals(status)) {
            // you will find a warning in the log
            return false;
        }       
        
        // everything is fine
        return true;
    }

    public void shutdown() {
    }
}
